require 'spec_helper'
require 'bonanza/link_helpers'
require 'bonanza/link_strategies'

RSpec.describe Bonanza::LinkHelpers do
  include Bonanza::LinkHelpers

  let(:expected_url) { nine_app_url(app, entity, reference) }
  let(:reference)    { 1234 }

  describe '.nine_app_url' do
    it 'raises an error when the app name is invalid' do
      expect do
        nine_app_url(:foobar, 1)
      end.to raise_exception 'Invalid app foobar'
    end

    it 'considers the Rails environment in staging' do
      allow(ENV).to receive(:fetch).with('RAILS_ENV', 'production').and_return('staging')
      expect(nine_app_url(:stats, :customer)).to start_with 'https://stats-staging.nine.ch'
    end

    it 'considers the Rails environment in development' do
      allow(ENV).to receive(:fetch).with('RAILS_ENV', 'production').and_return('development')
      expect(nine_app_url(:stats, :customer)).to start_with 'http://stats.dev'
    end
  end

  describe '.link_to_otrs_ticket' do
    let(:app) { :otrs }
    let(:entity) { :ticket }

    it 'creates a link to an otrs ticket' do
      markup = link_to_otrs_ticket('OTRS', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'OTRS'
    end
  end

  describe '.link_to_otrs_customer' do
    let(:app) { :otrs }
    let(:entity) { :customer }

    it 'creates a link to an otrs customer profile' do
      markup = link_to_otrs_customer('OTRS', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'OTRS'
    end
  end

  describe '.link_to_billing' do
    let(:app) { :billing }
    let(:entity) { :debtor }

    it 'creates a link to billing' do
      markup = link_to_billing('Billing', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'Billing'
    end
  end

  describe '.link_to_stats' do
    let(:app) { :stats }
    let(:entity) { :customer }

    it 'creates a link to stats' do
      markup = link_to_stats('Stats', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'Stats'
    end
  end

  describe '.link_to_redmine' do
    let(:app) { :redmine }
    let(:entity) { :issue }

    it 'creates a link to redmine' do
      markup = link_to_redmine('Redmine', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'Redmine'
    end
  end

  describe '.link_to_kuba_account' do
    let(:app) { :kuba }
    let(:entity) { :account }

    it 'creates a link to a kuba account' do
      markup = link_to_kuba_account('Kuba', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'Kuba'
    end
  end

  describe '.link_to_wiki_customer' do
    let(:app) { :wiki }
    let(:entity) { :customer }
    let(:reference) { 'prepress' }

    it 'creates a link to a wiki customer doc' do
      markup = link_to_wiki_customer('Wiki', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'Wiki'
    end
  end

  describe '.link_to_migration_item' do
    let(:app) { :yimin }
    let(:entity) { :item }
    let(:reference) { 12 }

    it 'creates a link to a Yimin migration item' do
      markup = link_to_migration_item('Migration', reference)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'Migration'
    end
  end
end
