require 'spec_helper'
require 'bonanza/urn_link_helpers'
require 'infrastructure_client/urn'

RSpec.describe Bonanza::UrnLinkHelpers do
  include Bonanza::UrnLinkHelpers

  let(:urn) { ::InfrastructureClient::Urn.new('urn:nine:vserver:1279') }

  describe '.link_to_urn' do
    let(:expected_url) { 'http://stats.test/admin/vserverdetail.php?id=1279' }

    it 'creates a link to a resource identified by urn' do
      markup = link_to_urn('My VServer', urn)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'My VServer'
    end

    it 'works with a string just as well' do
      markup = link_to_urn('My VServer', urn.to_s)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'My VServer'
    end

    it 'assigns the urn name if no name is provided' do
      markup = link_to_urn('', urn)
      expect(markup).to include "href=\"#{expected_url}\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include urn.short
    end

    it 'makes an empty link when urn is nil' do
      markup = link_to_urn('My VServer', nil)
      expect(markup).to include "href=\"\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'My VServer'
    end

    context 'urn as a string' do
      it 'makes an empty link when urn is invalid' do
        markup = link_to_urn('My VServer', 'some:wrong:urn')
        expect(markup).to include "href=\"\""
        expect(markup).to include "target=\"_blank\""
        expect(markup).to include 'My VServer'
      end
    end

    context 'urn as an object' do
      it 'makes an empty link when urn is invalid' do
        markup = link_to_urn('My VServer', ::InfrastructureClient::Urn.new('aaa:bbb:ccc'))
        expect(markup).to include "href=\"\""
        expect(markup).to include "target=\"_blank\""
        expect(markup).to include 'My VServer'
      end
    end

    it 'makes an empty link when the urn type is not found in urls' do
      urn = ::InfrastructureClient::Urn.new('urn:nine:foobar:1279')
      markup = link_to_urn('My VServer', urn)
      markup = link_to_urn('My VServer', urn.to_s)
      expect(markup).to include "href=\"\""
      expect(markup).to include "target=\"_blank\""
      expect(markup).to include 'My VServer'
    end

    context 'when the urn type has multiple parts' do
      let(:urn) { ::InfrastructureClient::Urn.new('urn:nine:ip:v4:subnet:1279') }
      let(:expected_url) { 'http://stats.test/admin/changesubnet.php?version=4&id=1279' }

      it 'creates a correct link' do
        markup = link_to_urn('My VServer', urn)
        expect(markup).to include "href=\"#{expected_url}\""
        expect(markup).to include "target=\"_blank\""
        expect(markup).to include 'My VServer'
      end
    end
  end
end
